SET FOREIGN_KEY_CHECKS=0;
-- ----------------------------
-- 模块表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_model`;
CREATE TABLE `mortals_sys_model` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `modelName` varchar(64) DEFAULT NULL COMMENT '模块名称',
  `modelCode` varchar(64) DEFAULT NULL COMMENT '模块编码',
  `modelIcon` varchar(64) DEFAULT NULL COMMENT '模块图标',
  `modelUrl` varchar(64) DEFAULT NULL COMMENT '模块地址',
  `remark` varchar(1024) DEFAULT NULL COMMENT '备注信息',
  `sort` int(9) DEFAULT 0 COMMENT '排序',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '模块表' ROW_FORMAT = Dynamic;


-- ----------------------------
-- 区域
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_area`;
CREATE TABLE `mortals_sys_area` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `ancestors` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT '' COMMENT '祖级列表，逗号分隔',
  `name` varchar(64) DEFAULT NULL COMMENT '区域名称',
  `iid` char(32) DEFAULT NULL COMMENT '一体化的ID号',
  `pid` char(32) DEFAULT NULL COMMENT '一体化的父id',
  `haveSonArea` char(5) DEFAULT NULL COMMENT '是否有下级区域（True.是，False.否）',
  `haveSonDept` char(5) DEFAULT NULL COMMENT '是否有下级部门（True.是，False.否）',
  `haveGetDept` char(5) DEFAULT NULL COMMENT '是否获取部门（true.是，false.否）',
  `haveGetMatterList` char(5) DEFAULT NULL COMMENT '是否获取事项列表（true.是，false.否）',
  `areaCode` char(32) DEFAULT NULL COMMENT '区域编码',
  `areaLevel` tinyint(2) DEFAULT '1' COMMENT '区域等级(1.省，2.地市州，3.区县，4.街道，5.社区)',
  `shortName` varchar(64) DEFAULT NULL COMMENT '名称简称',
  `domain` varchar(1024) DEFAULT NULL COMMENT '访问地址',
  `status` tinyint(2) DEFAULT '1' COMMENT '区域状态 (0.停用，1.正常)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '区域表' ROW_FORMAT = Dynamic;



-- ----------------------------
-- 站点表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_site`;
CREATE TABLE `mortals_sys_site` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteName` varchar(255) DEFAULT NULL COMMENT '站点名称',
  `siteCode` varchar(64) DEFAULT NULL COMMENT '站点编号',
  `areaID` varchar(32) DEFAULT NULL COMMENT '区域Id',
  `areaCode` varchar(32) DEFAULT NULL COMMENT '区域编号',
  `areaName` varchar(32) DEFAULT NULL COMMENT '区域名称',
  `proCode` varchar(32) DEFAULT NULL COMMENT '省编码',
  `cityCode` varchar(32) DEFAULT NULL COMMENT '市编码',
  `districtCode` varchar(32) DEFAULT NULL COMMENT '区编码',
  `siteIp` varchar(32) DEFAULT NULL COMMENT '站点服务器ip',
  `sitePort` varchar(8) DEFAULT NULL COMMENT '站点服务器端口',
  `longitude` varchar(32) DEFAULT NULL COMMENT '经度',
  `latitude` varchar(32) DEFAULT NULL COMMENT '纬度',
  `siteTel` varchar(32) DEFAULT NULL COMMENT '中心联系电话',
  `detailAddress` varchar(255) DEFAULT NULL COMMENT '中心详细地址',
  `siteRemark` text  COMMENT '中心介绍',
  `amWorkStartTime` datetime DEFAULT NULL COMMENT '上午上班开始时间',
  `amWorkEndTime` datetime DEFAULT NULL COMMENT '上午上班结束时间',
  `pmWorkStartTime` datetime DEFAULT NULL COMMENT '下午上班开始时间',
  `pmWorkEndTime` datetime DEFAULT NULL COMMENT '下午上班结束时间',
  `workday1` tinyint(2) DEFAULT '1' COMMENT '周一 (1.上班，0.不上)',
  `workday2` tinyint(2) DEFAULT '1' COMMENT '周二 (1.上班，0.不上)',
  `workday3` tinyint(2) DEFAULT '1' COMMENT '周三 (1.上班，0.不上)',
  `workday4` tinyint(2) DEFAULT '1' COMMENT '周四 (1.上班，0.不上)',
  `workday5` tinyint(2) DEFAULT '1' COMMENT '周五 (1.上班，0.不上)',
  `workday6` tinyint(2) DEFAULT '0' COMMENT '周六 (1.上班，0.不上)',
  `workday7` tinyint(2) DEFAULT '0' COMMENT '周日 (1.上班，0.不上)',
  `level` int(4) DEFAULT 1 COMMENT '楼层',
  `building` int(4) DEFAULT 1 COMMENT '楼栋',
  `modelIds` varchar(256) DEFAULT '' COMMENT '部署模块，逗号分隔',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '站点表' ROW_FORMAT = Dynamic;


-- ----------------------------
-- 业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_business`;
CREATE TABLE `mortals_sys_business` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `parentId` bigint(20) DEFAULT NULL COMMENT '父级ID',
  `ancestors` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT '' COMMENT '祖级列表，逗号分隔',
  `isBusiness` tinyint(2) DEFAULT NULL COMMENT '业务类型(0.一级业务,1.二级业务)',
  `name` varchar(32) DEFAULT NULL COMMENT '业务名称',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `canorder` tinyint(2) DEFAULT '1' COMMENT '是否允许预约（1.允许，0.不允许）',
  `cantake` tinyint(2) DEFAULT '1' COMMENT '是否允许取号（1.允许，0.不允许）',
  `datashow` tinyint(2) DEFAULT '1' COMMENT '大厅情况展示 （1.展示，0.不展示）',
  `englishname` varchar(64) DEFAULT NULL COMMENT '英语业务名',
  `flownum` varchar(8) DEFAULT NULL COMMENT '流水编号如A、B',
  `businessType` tinyint(2) DEFAULT '1' COMMENT '业务类型 (0.一体化业务，1.自建业务)',
  `status` tinyint(2) DEFAULT '1' COMMENT '业务状态 (0.停用，1.正常)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '站点业务表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- 站点业务表
-- ----------------------------
CREATE TABLE `mortals_sys_site_business` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点ID',
  `siteName` varchar(255) DEFAULT NULL COMMENT '站点名称',
  `ancestors` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT '' COMMENT '祖级列表，逗号分隔',
  `businessId` bigint(20) DEFAULT NULL COMMENT '业务ID',
  `isBusiness` tinyint(2) DEFAULT NULL COMMENT '业务类型(0.一级业务,1.二级业务)',
  `parentId` bigint(20) DEFAULT NULL COMMENT '业务父级ID',
  `businessName` varchar(1024) DEFAULT NULL COMMENT '业务名称',
  `status` tinyint(2) DEFAULT '1' COMMENT '业务状态 (0.停用，1.正常)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20) DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=46 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='站点业务表';

-- ----------------------------
-- 站点事项表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_site_matter`;
CREATE TABLE `mortals_sys_site_matter` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点ID',
  `siteName` varchar(255) DEFAULT NULL COMMENT '站点名称',
  `matterId` bigint(20) DEFAULT NULL COMMENT '事项ID',
  `matterName` varchar(1024) DEFAULT NULL COMMENT '事项名称',
  `deptId` bigint(20) DEFAULT NULL COMMENT '部门ID',
  `deptName` varchar(64) DEFAULT NULL COMMENT '部门名称',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '站点事项表' ROW_FORMAT = Dynamic;


-- ----------------------------
-- 业务事项关联表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_business_matter`;
CREATE TABLE `mortals_sys_business_matter` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点ID',
  `siteName` varchar(255) DEFAULT NULL COMMENT '站点名称',
  `siteBusinessId` bigint(20) DEFAULT NULL COMMENT '业务id',
  `siteBusinessName` varchar(64) DEFAULT NULL COMMENT '业务名称',
  `matterId` bigint(20) DEFAULT NULL COMMENT '事项id',
  `matterName` varchar(64) DEFAULT NULL COMMENT '事项名称',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '业务事项关联表' ROW_FORMAT = Dynamic;



-- ----------------------------
-- 站点部门
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_dept`;
CREATE TABLE `mortals_sys_dept` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `tid` varchar(128) DEFAULT NULL COMMENT '从政务系统来的部门id',
  `tname` varchar(128) DEFAULT NULL COMMENT '从政务系统来的部门name',
  `name` varchar(64) DEFAULT NULL COMMENT '部门名称',
  `simpleName` varchar(128) DEFAULT NULL COMMENT '从政务系统来的别名',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点ID',
  `deptAbb` varchar(32) DEFAULT NULL COMMENT '部门简称',
  `deptTelphone` varchar(32) DEFAULT NULL COMMENT '部门电话',
  `deptNumber` varchar(32) DEFAULT NULL COMMENT '部门编号',
  `isAutotable` tinyint(1) DEFAULT '1' COMMENT '填单机展示 (0.否，1.是) ',
  `isOrder` tinyint(1) DEFAULT '1' COMMENT '预约展示 (0.否，1.是) ',
  `isBkb` tinyint(1) DEFAULT '1' COMMENT '背靠背展示 (0.否，1.是) ',
  `isWorkGuide` tinyint(1) DEFAULT '1' COMMENT '办事指南展示 (0.否，1.是) ',
  `usValid` tinyint(1) DEFAULT '1' COMMENT '是否使用 (0.否，1.是) ',
  `isSecphone` tinyint(1) DEFAULT '1' COMMENT '部门电话是否展示 (0.否，1.是) ',
  `isEnglish` tinyint(1) DEFAULT '1' COMMENT '是否展示英文 (0.否，1.是) ',
  `sort` int(4) DEFAULT 0 COMMENT '排序',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
   PRIMARY KEY (`id`)
)  ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '部门表' ROW_FORMAT = Dynamic;


-- ----------------------------
-- 站点部门窗口表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_window`;
CREATE TABLE `mortals_sys_window` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点ID',
  `siteName` varchar(255) DEFAULT NULL COMMENT '站点名称',
  `deptId` bigint(20) DEFAULT NULL COMMENT '部门ID',
  `deptName` varchar(64) DEFAULT NULL COMMENT '部门名称',
  `name` varchar(64) DEFAULT NULL COMMENT '窗口名称',
  `englishName` varchar(64) DEFAULT NULL COMMENT '英语窗口名',
  `region` varchar(32) DEFAULT NULL COMMENT '区域',
  `englishRegion` varchar(64) DEFAULT NULL COMMENT '英语区域',
  `fromnum` varchar(64) DEFAULT NULL COMMENT '窗口编号',
  `hongqi` tinyint(1) DEFAULT '1' COMMENT '红旗窗口 (1.是，0.否)',
  `summary` varchar(255) DEFAULT NULL COMMENT '备注',
  `building` tinyint(2) DEFAULT 1 COMMENT '楼栋',
  `level` tinyint(2) DEFAULT 1 COMMENT '楼层',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '站点部门窗口表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- 窗口业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_window_business`;
CREATE TABLE `mortals_sys_window_business` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `windowId` bigint(20) DEFAULT NULL COMMENT '窗口id',
  `windowName` varchar(255) DEFAULT NULL COMMENT '窗口名称',
  `siteBusinessId` bigint(20) DEFAULT NULL COMMENT '站点业务ID',
  `businessName`varchar(255) DEFAULT NULL COMMENT '业务名称',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '窗口业务表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- 窗口事项表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_window_matter`;
CREATE TABLE `mortals_sys_window_matter` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `windowId` bigint(20) DEFAULT NULL COMMENT '窗口ID',
  `windowName` varchar(255) DEFAULT NULL COMMENT '窗口名称',
  `siteMatterId` bigint(20) DEFAULT NULL COMMENT '站点事项ID',
  `matterName` varchar(255) DEFAULT NULL COMMENT '事项名称',
  `deptId` bigint(20) DEFAULT NULL COMMENT '部门ID',
  `deptName` varchar(64) DEFAULT NULL COMMENT '部门名称',
  `isShow` tinyint(1) DEFAULT '1' COMMENT '是否显示 (1.是，0.否)',
  `sort` int(4) DEFAULT 0 COMMENT '排序',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '窗口事项表' ROW_FORMAT = Dynamic;


-- ----------------------------
-- 工作人员表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_workman`;
CREATE TABLE mortals_sys_workman(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `loginName` varchar(64)     COMMENT '用户登录名',
    `loginPwd` varchar(128)     COMMENT '密码',
    `deptId` bigint(20)     COMMENT '部门id号',
    `deptName` varchar(64)     COMMENT '部门名称',
    `windowId` bigint(20)     COMMENT '窗口id号',
    `windowName` varchar(64)     COMMENT '窗口名称',
    `siteId` bigint(20)     COMMENT '站点ID',
    `siteName` varchar(64)     COMMENT '站点名称',
    `name` varchar(64)     COMMENT '姓名',
    `number` varchar(64)     COMMENT '工号',
    `userpost` varchar(64)     COMMENT '职务',
    `posttitle` varchar(64)     COMMENT '职称',
    `politicalstatus` tinyint(2)     COMMENT '政治面貌 （0.中共党员，1.中共预备党员，2.共青团员，3.普通居民，4.其它)',
    `dangyuan` tinyint(2)     COMMENT '党员 （0.非党员，1.党员，2.党员示范岗，3.党员先锋岗)',
    `phone` varchar(64)     COMMENT '电话',
    `mobile` varchar(64)     COMMENT '手机',
    `starlevel` tinyint(2)     COMMENT '星级',
    `summary` varchar(255)     COMMENT '个人简介',
    `photoPath` varchar(255)     COMMENT '照片',
    `duty` mediumtext     COMMENT '岗位职责',
    `promise` mediumtext     COMMENT '服务承诺',
    `business` mediumtext     COMMENT '办理事项',
    `online` tinyint(2)     COMMENT '是否在线（0.离线，1.在线，2.暂离,3.点击暂离,4.回归,5.登陆）',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `updateTime` datetime     COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='工作人员';

-- ----------------------------
-- 基础事项表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter`;
CREATE TABLE `mortals_sys_matter` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点ID',
  `tid` varchar(128) DEFAULT NULL COMMENT '从政务系统来的事项id',
  `tcode` varchar(128) DEFAULT NULL COMMENT '从政务系统来的事项code',
  `tname` varchar(255) DEFAULT NULL COMMENT '从政务系统来的事项name',
  `matterName` varchar(64) DEFAULT NULL COMMENT '事项名称',
  `englishName` varchar(256) DEFAULT '' COMMENT '英语事项名',
  `matterNo` varchar(64) DEFAULT NULL COMMENT '事项编号',
  `belongDept` varchar(64) DEFAULT NULL COMMENT '所属部门',
  `appoveObjectShow` varchar(16) DEFAULT '事业法人' COMMENT '服务对象 （事业法人.事业法人，社会组织法人.社会组织法人，非法人企业.非法人企业，企业法人.企业法人，自然人.自然人，其他组织.其他组织）',
  `operatScopeShow` varchar(64) DEFAULT '无' COMMENT '通办范围 （无.无，全国.全国，全市.全市，全县.全县，全镇[乡 街道].全镇[乡 街道]，跨村[社区].跨村[社区]）',
  `appoveTimeLimitShow` varchar(16) DEFAULT '网络办件' COMMENT '办件类型（网络办件.网络办件，行政审批一般件.行政审批一般件，综合窗口件.综合窗口件）',
  `handleType` varchar(12) DEFAULT '窗口办理' COMMENT '办理形式（窗口办理.窗口办理，网上办理.网上办理）	',
  `legalTimeLimitShow` varchar(32) DEFAULT NULL COMMENT '法定办结时限',
  `legalEndExplain` varchar(255) DEFAULT NULL COMMENT '法定时限办结说明',
  `promiseTimeLimitShow` varchar(32) DEFAULT NULL COMMENT '承诺办结时限',
  `promiseEndExplain` varchar(255) DEFAULT NULL COMMENT '承诺时限办结说明',
  `isChargesShow` varchar(16) DEFAULT '否' COMMENT '是否收费（否.否，是.是）',
  `certificationLevelsShow` varchar(64) DEFAULT '实名认证' COMMENT '认证等级需求（实名认证.实名认证，单次面签.单次面签，每次面签.每次面签）',
  `planTakeTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '计划生效日期',
  `promiseTakeTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '承诺生效日期',
  `specialProcedure` varchar(64) DEFAULT NULL COMMENT '特别程序',
  
  `windowToTheSceneNum` tinyint(2) DEFAULT NULL COMMENT '窗口到现场次数',
  `isOnlineSubscribeShow` varchar(64) DEFAULT '否' COMMENT '是否网上预约,窗口办理选（否.否，是.是）',
  `isExpressTakeShow` varchar(16) DEFAULT '否' COMMENT '物流快递,窗口办理选（否.否，是.是）',
  `isProvinceAcquisitionShow` varchar(16) DEFAULT '否' COMMENT '是否支持全省范围就近取件（否.否，是.是）',
  `isApplyProvinceShow` varchar(16) DEFAULT '否' COMMENT '是否支持全省范围就近办理（否.否，是.是）',
  `mustSceneExplain` varchar(512) DEFAULT NULL COMMENT '必须到现场原因',
  
  `onlineType` varchar(32) DEFAULT '原件预审' COMMENT '网办类型（原件预审.原件预审，原件核验.原件核验，全程网办.全程网办）',
  `onlineToTheSceneNum` tinyint(2) DEFAULT '0' COMMENT '网办到现场次数',
  `onlineOperatDeep` varchar(16) DEFAULT '互联网咨询' COMMENT '网络办理深度（互联网咨询.互联网咨询，互联网收件.互联网收件，互联网预审.互联网预审，互联网受理.互联网受理，互联网办理.互联网办理，互联网办理结果信息反馈.互联网办理结果信息反馈，其他.其他）',
  `isExpressTakeOnlineShow` varchar(16) DEFAULT NULL COMMENT '物流快递，网上办理选（否.否，是.是）',
  `isDoorTakeShow` varchar(16) DEFAULT '否' COMMENT '是否支持上门收取申请（否.否，是.是）',
  `onlineMustSceneExplain` varchar(512) DEFAULT NULL COMMENT '网上必须到现场原因',
  
  `performDeptType` varchar(64) DEFAULT NULL COMMENT '实施主体',
  `matterEdition` varchar(32) DEFAULT NULL COMMENT '事项版本',
  `eventTypeShow` varchar(128) DEFAULT '行政许可' COMMENT '事项类型名称（行政许可.行政许可，行政处罚.行政处罚，行政强制.行政强制，行政征收.行政征收，行政给付.行政给付，行政检查.行政检查，行政确认.行政确认，行政奖励.行政奖励，行政裁决.行政裁决，其他行政权力.其他行政权力，主动服务.主动服务，依申请服务.依申请服务，咨询查询.咨询查询，未归类事项.未归类事项）',
  `performHierarchyShow` varchar(128) DEFAULT NULL COMMENT '行使层级名称（省级.省级，市级.市级，县级.县级，镇[乡 街道].镇[乡 街道]，村[社区]级.村[社区]级）',
  `powerSourceShow` varchar(64) DEFAULT NULL COMMENT '权力来源（法定本级行使.法定本级行使，上级下放.上级下放，上级授权.上级授权，同级授权.同级授权，上级委托.上级委托，同级委托.同级委托）',
  `performDeptTypeShow` varchar(64) DEFAULT NULL COMMENT '实施主体性质（法定机关.法定机关，授权组织.授权组织，受委托组织.受委托组织）',
  `goveServiceCenterShow` varchar(16) DEFAULT '否' COMMENT '是否进驻中心（否.否，是.是）',
  `isConvenientCenterShow` varchar(16) DEFAULT '否' COMMENT '是否纳入便民服务中心（否.否，是.是）',
  `terminalHandle` varchar(20) DEFAULT '是' COMMENT '自助终端办理 （否.否，是.是）',
  `isOnline` varchar(20) DEFAULT '是' COMMENT '是否网办 （否.否，是.是）',
  `isOnlinePayShow` varchar(16) DEFAULT '是' COMMENT '支持网上支付（否.否，是.是）',
  `entrustmentDepartmen` varchar(64) DEFAULT '是' COMMENT '委托部门（否.否，是.是）',
  `jointInfoShow` varchar(128) DEFAULT NULL COMMENT '联办机构',
  `matterStatus` varchar(32) DEFAULT '在用' COMMENT '事项状态（停用.停用，在用.在用）',
  `numberLimit` int(11) DEFAULT NULL COMMENT '数量限制',
  `type` varchar(32) DEFAULT '' COMMENT '主题类型',
  `baseCode` varchar(128) DEFAULT NULL COMMENT '基本编码',
  `implementCode` varchar(128) DEFAULT NULL COMMENT '实施编码',
  `implementBodyCode` varchar(128) DEFAULT NULL COMMENT '实施主体编码',
  `operateItemCode` varchar(128) DEFAULT NULL COMMENT '办理项编码',
  `townshipName` varchar(128) DEFAULT NULL COMMENT '乡镇街道名称',
  `townshipCode` varchar(128) DEFAULT NULL COMMENT '乡镇街道代码',
  `villageName` varchar(128) DEFAULT NULL COMMENT '村居社区名称',
  `villageCode` varchar(128) DEFAULT NULL COMMENT '村居社区代码',
  `operateTime` varchar(128) DEFAULT NULL COMMENT '办理时间',
  `operateSite` varchar(1024) DEFAULT NULL COMMENT '办理地点',
  `cousultingShow` varchar(1024) DEFAULT NULL COMMENT '咨询方式',
  `cousultingTelephoneShow` varchar(64) DEFAULT NULL COMMENT '咨询电话',
  `superviseShow` varchar(1024) DEFAULT NULL COMMENT '监督投诉方式',
  `sort` int(4) DEFAULT NULL COMMENT '排序',
  `source` tinyint(2) DEFAULT '1' COMMENT '事项来源(0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '基础事项表' ROW_FORMAT = Dynamic;


-- ----------------------------
-- 事项材料表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_datum`;
CREATE TABLE `mortals_sys_matter_datum` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键，自增长',
  `matterId` bigint(20)  COMMENT '事项id',
  `matterName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '事项名称',
  `materialName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '材料名',
  `isMust` varchar(32) DEFAULT '非必要' COMMENT '必交性（非必要.非必要，必要.必要，必要|容缺后补.必要|容缺后补，非必要|容缺后补.非必要|容缺后补）',
  `materialType`  varchar(32) DEFAULT '无'  COMMENT '材料类型（无.无，原件.原件，复印件.复印件，原件和复印件.原件和复印件)',
  `materialProperty` varchar(32)  DEFAULT '纸质' COMMENT '材料形式（纸质.纸质，电子.电子，纸质|电子.纸质|电子）',
  `electronicgs` varchar(32) DEFAULT '无' COMMENT '电子材料格式（无.无，不限.不限，jpg.jpg，jpeg.jpeg，pdf.pdf，word.word，pdf|jpg|jpeg.pdf|jpg|jpeg，pdf|jpg.pdf|jpg）',
  `materialSource` varchar(32)  DEFAULT '无' COMMENT '材料来源渠道（无.无，申请人自备.申请人自备，政府部门核发.政府部门核发，其他.其他）',
  `paperNum` int(4) DEFAULT '1' COMMENT '纸质材料份数',
  `paperGg` varchar(32) COMMENT '纸质材料规格',
  `jianmMs` varchar(32) DEFAULT '无' COMMENT '减免模式（无.无，减.减，免.免）',
  `sealWay` varchar(32)  COMMENT '盖章方式',
  `isjianm` varchar(32) DEFAULT '是' COMMENT '是否减免（否.否，是.是）',
  `isLack` varchar(32) DEFAULT '必要' COMMENT '材料是否容缺（必要.必要，非必要.非必要）',
  `ybUrl` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT '' COMMENT '材料地址',
  `materialSourceSm` varchar(512) DEFAULT '' COMMENT '来源渠道说明',
  `remarkSub` text CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '填报须知',
  `clauseContent` text CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '要求提供材料的依据',
  `summary` text CHARACTER SET utf8 COLLATE utf8_general_ci   COMMENT '受理标准',
  `remark` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci   COMMENT '备注',
  `source` tinyint(2) DEFAULT '1' COMMENT '事项来源(0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='事项申请材料';

-- ----------------------------
-- 事项材料附件表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_datum_file`;
CREATE TABLE `mortals_sys_matter_datum_file` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键，自增长',
  `datumId` bigint(20) DEFAULT NULL COMMENT '材料id',
  `materialName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '材料名',
  `fileName` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '附件名称',
  `fileUrl` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '附件下载地址',
  `filetype` varchar(20) DEFAULT '示例样表' COMMENT '附件类型 (示例样表.示例样表，空白表格.空白表格)',
  `source` tinyint(2) DEFAULT '1' COMMENT '附件来源 (0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='材料附件表';

-- ----------------------------
-- 事项受理条件表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_accept`;
CREATE TABLE `mortals_sys_matter_accept` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键，自增长',
  `matterId` bigint(20) NOT NULL DEFAULT '0' COMMENT '基础事项表id',
  `matterName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '事项名称',
  `content` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '受理条件',
  `source` tinyint(2) DEFAULT '1' COMMENT '事项来源 (0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20) DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='事项受理条件';

-- ----------------------------
-- 事项办理流程表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_flowlimit`;
CREATE TABLE `mortals_sys_matter_flowlimit` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键，自增长',
  `matterId` bigint(20) NOT NULL DEFAULT '0' COMMENT '事项基础表id',
  `matterName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '事项名称',
  `flowName` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '办理流程',
  `flowTime` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '办理时长',
  `flowLimit` varchar(256) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '转外时限',
  `flowDesc` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '办理流程说明',
  `source` tinyint(2) DEFAULT '1' COMMENT '事项来源(0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='事项办理流程';

-- ----------------------------
-- 事项收费标准表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_charges`;
CREATE TABLE `mortals_sys_matter_charges` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键，自增长',
  `matterId` bigint(20) NOT NULL DEFAULT '0' COMMENT '事项基础表matter id',
  `matterName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '事项名称',
  `content` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '收费标准',
  `source` tinyint(2) DEFAULT '1' COMMENT '事项来源，(0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='事项收费标准';

-- ----------------------------
-- 事项设定依据表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_setbase`;
CREATE TABLE `mortals_sys_matter_setbase` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键，自增长',
  `matterId` bigint(20) NOT NULL DEFAULT '0' COMMENT '事项matter id',
  `matterName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '事项名称',
  `policyName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '法规标题',
  `policyType` varchar(32) DEFAULT '法律'  COMMENT '法规类型，(法律.法律，行政法规.行政法规，地方法规.地方法规，部门规章.部门规章，其他.其他，政府规章.政府规章，规范性文件.规范性文件)',
  `policyitem` varchar(1024)  COMMENT '条例',
  `content` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '条款内容',
  `source` tinyint(2) DEFAULT '1' COMMENT '事项来源，(0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20) NULL DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='事项设定依据表';

-- ----------------------------
-- 事项中介服务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_intermediary`;
CREATE TABLE `mortals_sys_matter_intermediary` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键，自增长',
  `matterId` bigint(20) NOT NULL DEFAULT '0' COMMENT '事项matter id',
  `matterName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '事项名称',
  `title` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '中介服务事项名称',
  `intermediaryRequest` text CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '中介服务实施机构及资质资格要求',
  `intermediaryRequestTime` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '服务时限',
  `remark` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备注',
  `source` tinyint(2) DEFAULT '0' COMMENT '事项来源，(0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='事项中介服务表';

-- ----------------------------
-- 事项常见问题表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_question`;
CREATE TABLE `mortals_sys_matter_question` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键，自增长',
  `matterId` bigint(20) NOT NULL DEFAULT '0' COMMENT '事项基础表matter id',
  `matterName` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci  COMMENT '事项名称',
  `question` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '问题',
  `answer` varchar(2048) CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '回答',
  `source` tinyint(2) DEFAULT '0' COMMENT '事项来源，(0.政务网，1.自定义)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='事项常见问题';


-- ----------------------------
-- 短信设置
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_sms_set`;
CREATE TABLE `mortals_sys_sms_set` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点id',
  `siteName` varchar(255) DEFAULT NULL COMMENT '站点名称',
  `sign` varchar(64) DEFAULT NULL COMMENT '短信签名',
  `lastnum` int(11) DEFAULT NULL COMMENT '剩余短信条数',
  `username` varchar(64) DEFAULT NULL COMMENT '用户名',
  `messageoff` tinyint(1) DEFAULT '1' COMMENT '短信开关 (1.开,0.关)',
  `smsplatform` tinyint(1) DEFAULT '1' COMMENT '短信平台 (1.容联,2.阿里云,3.移动)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '短信设置' ROW_FORMAT = Dynamic;

-- ----------------------------
-- 短信模板表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_sms_template`;
CREATE TABLE `mortals_sys_sms_template` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteid` bigint(20) DEFAULT NULL COMMENT '站点ID',
  `siteName` varchar(255) DEFAULT NULL COMMENT '站点名称',
  `code` varchar(64) DEFAULT NULL COMMENT '模板code',
  `summary` varchar(256) DEFAULT NULL COMMENT '备注',
  `content` varchar(256) DEFAULT NULL,
  `type` tinyint(2) DEFAULT '1' COMMENT '模板选择 (1.预约成功短信,2.取号成功短信,3.临近叫号短信)',
  `source` tinyint(2) DEFAULT '1' COMMENT '系统来源(1.排号系统,2.取件系统）',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20) DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '短信模板表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- 节假日
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_holiday`;
CREATE TABLE `mortals_sys_holiday` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点ID',
  `siteName` varchar(255) DEFAULT NULL COMMENT '站点名称',
  `name` varchar(64) DEFAULT NULL COMMENT '节日名称',
  `summary` varchar(256) DEFAULT NULL COMMENT '备注',
  `year` int(4) DEFAULT NULL COMMENT '年份',
  `startTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '开始时间',
  `endTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '结束时间',
  `workorholiday` tinyint(2) DEFAULT '0' COMMENT '是否工作日（0.节假日,1.工作日)',
  `createTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `createUserId` bigint(20)  DEFAULT NULL COMMENT '创建用户',
  `updateTime` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE = InnoDB  CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '节假日表' ROW_FORMAT = Dynamic;



-- ----------------------------
-- 产品表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_product`;
CREATE TABLE mortals_xhx_product(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '主键ID，主键，自增长',
    `productName` varchar(64) NOT NULL    COMMENT '产品名称',
    `productCode` varchar(256) NOT NULL    COMMENT '产品编码',
    `productRemark` varchar(256)     COMMENT '备注',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
    `updateUserId` bigint(20)     COMMENT '更新用户',
    `updateTime` datetime     COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='产品';
-- ----------------------------
-- 系统基础皮肤表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_skin_base`;
CREATE TABLE mortals_sys_skin_base(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `categoryId` bigint(20)     COMMENT '所属种类,来源种类',
    `productId` bigint(20)     COMMENT '产品id',
    `productName` varchar(256) NOT NULL    COMMENT '产品名称',
    `cssFilePath` varchar(256)     COMMENT 'css模板合成后文件地址',
    `name` varchar(256) NOT NULL    COMMENT '产品皮肤名称，唯一且不为空',
    `imageResolution` varchar(256) NOT NULL    COMMENT '分辨率 (1.1920*1080，2.1080*1920，3.1280*1280)',
    `previewImagePath` varchar(256) NOT NULL    COMMENT '预览图片',
    `sortNum` int(9)     COMMENT '排序编号',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `updateTime` datetime     COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统基础皮肤';


-- ----------------------------
-- 系统皮肤模板表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_skin_template`;
CREATE TABLE mortals_sys_skin_template(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `productId` bigint(20)     COMMENT '产品ID',
    `productName` varchar(64)     COMMENT '产品名称',
    `templateName` varchar(64)     COMMENT '模板名称',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `updateTime` datetime     COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统皮肤模板';
-- ----------------------------
-- 皮肤属性字段配置表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_skin_field`;
CREATE TABLE mortals_sys_skin_field(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `skinId` bigint(20)     COMMENT '皮肤id',
    `templateId` bigint(20)     COMMENT '模板id,不为空时为模板配置属性',
    `fieldCode` varchar(64)     COMMENT '字段编码',
    `fieldName` varchar(64)     COMMENT '字段名称',
    `fieldType` varchar(64)     COMMENT '数据类型（1.颜色，2.图片地址）',
    `fieldValue` varchar(64)     COMMENT '字段值',
    `fieldLen` int(9)     COMMENT '数据长度，默认100',
    `fieldNull` tinyint(2)     COMMENT '是否允许为空，0否1是',
    `fieldOrderNo` varchar(64)     COMMENT '排序号',
    `remark` varchar(1024)     COMMENT '备注',
    `enabled` tinyint(2)     COMMENT '是否启用，0否1是',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `updateTime` datetime     COMMENT '修改时间',
    `updateUserId` bigint(20)     COMMENT '修改用户',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='皮肤属性字段配置';
-- ----------------------------
-- 系统皮肤分类表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_skin_category`;
CREATE TABLE mortals_sys_skin_category(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `name` varchar(64)     COMMENT '分类名称',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `updateTime` datetime     COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统皮肤分类';


