package com.mortals.xhx.common.utils;

import com.mortals.xhx.base.framework.config.FreemarkerApplicationConfig;
import com.mortals.xhx.common.key.GenConstants;
import freemarker.template.Configuration;
import freemarker.template.Template;
import freemarker.template.TemplateException;
import freemarker.template.TemplateExceptionHandler;
import lombok.SneakyThrows;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;


public class FreeMarkerUtils {


    /**
     * 项目空间路径
     */
    private static final String PROJECT_PATH = "main/java";
    private static final String TEST_PATH = "test/java/com/mortals/httpclient";

    /**
     * mybatis空间路径
     */
    private static final String MYBATIS_PATH = "main/resources/sqlmap";

    /**
     * 默认上级菜单，系统工具
     */
    private static final String DEFAULT_PARENT_MENU_ID = "3";

    public static Configuration cfg = null;

    public static StringBuilder dbSql = new StringBuilder();
    public static StringBuilder menuSql = new StringBuilder();
    public static StringBuilder paramsSql = new StringBuilder();
    public static StringBuilder apimd = new StringBuilder();
    public static StringBuilder apitwomd = new StringBuilder();
    public static StringBuilder apidict = new StringBuilder();

    /**
     * 初始化freeMaker方法
     */
    @SneakyThrows
    public static void initFreeMarker(String path) {
        //初始化模板引擎
        cfg = new Configuration(Configuration.VERSION_2_3_29);
        cfg.setClassForTemplateLoading(FreemarkerApplicationConfig.class, "/template/");
        //cfg.setClassForTemplateLoading(FreemarkerApplicationConfig.class,"/template/sql");
        //指定模板文件存放的地方
        //cfg.setDirectoryForTemplateLoading(new File(System.getProperty("user.dir") + "\\government-manager\\target\\classes\\template\\java"));
        //cfg.setDirectoryForTemplateLoading(new File(System.getProperty("user.dir") + "\\government-manager\\target\\classes\\template\\xml\\"));
        //cfg.set

        // cfg.setTemplateLoader(new ClassTemplateLoader(FreeMarkerUtils.class,"/template/java/entity.ftl"));

        // cfg.setClassForTemplateLoading(FreeMarkerUtils.class, "/template/");
        // cfg.setClassForTemplateLoading(FreeMarkerUtils.class, "\\template\\sql");
        //cfg.setClassForTemplateLoading(FreeMarkerUtils.class, "\\template\\vue");
        //cfg.setClassForTemplateLoading(FreeMarkerUtils.class, "\\template\\xml");
        //设置字符编码集
        cfg.setDefaultEncoding("UTF-8");
        //设置异常的处理方式
        cfg.setTemplateExceptionHandler(TemplateExceptionHandler.RETHROW_HANDLER);
        //设置输出时间格式
        cfg.setDateFormat("yyyy-MM-dd HH:mm:ss");

    }

    /**
     * 初始化freeMaker方法
     */
    @SneakyThrows
    public static void initFreeMarkerPath(String templatePath) {
        //初始化模板引擎
        cfg = new Configuration(Configuration.VERSION_2_3_29);
        cfg.setDirectoryForTemplateLoading(new File(templatePath));

        //设置字符编码集
        cfg.setDefaultEncoding("UTF-8");
        //设置异常的处理方式
        cfg.setTemplateExceptionHandler(TemplateExceptionHandler.RETHROW_HANDLER);
        //设置输出时间格式
        cfg.setDateFormat("yyyy-MM-dd HH:mm:ss");

    }


    /**
     * 获取模板信息
     *
     * @return 模板列表
     */
    public static List<String> getTemplateList(String tplCategory) {
        List<String> templates = new ArrayList<String>();
        templates.add("vo.java.ftl");
        templates.add("enum.java.ftl");
        templates.add("entity.java.ftl");
        templates.add("entityQuery.java.ftl");
        templates.add("dao.java.ftl");
        templates.add("daoImpl.java.ftl");
        // templates.add("web.java.ftl");
        templates.add("webBody.java.ftl");
        templates.add("webForm.java.ftl");
        templates.add("sqlMap.xml.ftl");
        templates.add("db.sql.ftl");
        templates.add("menu.sql.ftl");
        templates.add("params.sql.ftl");
        templates.add("api.md.ftl");
        templates.add("api-two.md.ftl");
        templates.add("apidict.md.ftl");
        templates.add("httpclient.test.ftl");
        if (GenConstants.TPL_CRUD.equals(tplCategory)) {
            templates.add("service.java.ftl");
            templates.add("serviceImpl.java.ftl");
            templates.add("webVueList.vue.ftl");
            templates.add("VueDialogShow.vue.ftl");
            // templates.add("webVueShow.vue.ftl");
        } else if (GenConstants.TPL_TREE.equals(tplCategory)) {
            templates.add("entity-tree.java.ftl");
            templates.add("service-tree.java.ftl");
            templates.add("serviceImpl-tree.java.ftl");
            templates.add("VueTreeDialogShow.vue.ftl");
            templates.add("webVueTreeList.vue.ftl");
        } else if (GenConstants.TPL_SUB.equals(tplCategory) || GenConstants.TPL_SUB_ONE.equals(tplCategory)) {
            templates.add("service.java.ftl");
            templates.add("serviceImpl.java.ftl");
            templates.add("webVueList.vue.ftl");
            //templates.add("webVueShow.vue.ftl");
            templates.add("VueDialogShow.vue.ftl");
        }
        //templates.add("webVueView.vue.ftl");
        return templates;
    }



    // 获取模板对象
    public static Template getTemplate(String templateName) {
        try {
            return cfg.getTemplate(templateName);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }


    /**
     * 提供模板文件，输出到控制台
     *
     * @param templateName 模板对象
     * @param dataModel    数据模型
     */
    public static void printConsole(String templateName, Map dataModel) {
        Template template = getTemplate(templateName);
        try {
            template.process(dataModel, new PrintWriter(System.out));
        } catch (TemplateException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }


    /**
     * 提供模板文件名称，输出到文件中
     *
     * @param templateName 模板对象
     * @param dataModel    数据模型
     * @param destFile     目标文件地址
     */
    public static String printFile(String templateName, Map dataModel, String destFile) {
        System.out.println(destFile);
        Template template = getTemplate(templateName);
        try {
            template.process(dataModel, new FileWriter(new File(destFile)));

        } catch (TemplateException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return destFile;
    }

    public static String printFile(String templateName, List<Map> dataModel, String destFile) {
        Template template = getTemplate(templateName);
        try {
            template.process(dataModel, new FileWriter(new File(destFile)));

        } catch (TemplateException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return destFile;
    }

    public static void main(String[] args) {


    }

}
