package com.mortals.xhx.daemon.applicationservice;

import com.mortals.framework.model.Context;
import com.mortals.framework.service.ICacheService;
import com.mortals.framework.springcloud.config.web.BaseWebMvcConfigurer;
import com.mortals.framework.util.ThreadPool;
import com.mortals.xhx.base.system.user.model.UserEntity;
import com.mortals.xhx.base.system.user.model.UserQuery;
import com.mortals.xhx.base.system.user.service.UserService;
import com.mortals.xhx.common.utils.SyncTreeSiteThread;
import com.mortals.xhx.module.site.model.SiteTreeSelect;
import com.mortals.xhx.module.site.service.SiteService;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Component;

import com.mortals.framework.springcloud.service.IApplicationStartedService;

import java.util.List;

/**
 * 应用级服务，在应用启动后、停止过程中调用
 * 应用已经完成启动完成，才调用该服务
 * 应用场景：
 * 1、应用任务，应用启动后定时或间隔执行的任务
 * 2、Socket服务端
 *
 * @author GM
 * @date 2020年7月15日
 */
@Component
public class DemoStartedService implements IApplicationStartedService {

    private static Log logger = LogFactory.getLog(DemoStartedService.class);

    @Autowired
    private SiteService siteService;
    @Autowired
    private ICacheService cacheService;

    @Autowired
    private UserService userService;

    @Override
    public void start() {
        logger.info("开始服务..[初始化用户站点树]");
        UserEntity userEntity = new UserEntity();
        userEntity.initAttrValue();
        userEntity.setId(0L);
        Context contextTemp = new Context();
        contextTemp.setUser(userEntity);
        SyncTreeSiteThread syncTreeSiteThread = new SyncTreeSiteThread(siteService, contextTemp);
        ThreadPool.getInstance().execute(syncTreeSiteThread);
        userService.find(new UserQuery()).stream().forEach(user->{
            Context context = new Context();
            context.setUser(user);
            ThreadPool.getInstance().execute(new SyncTreeSiteThread(siteService,context));
        });
    }

    @Override
    public void stop() {
        logger.info("停止服务..");
    }

    @Override
    public int getOrder() {
        return 10;
    }

}
