package com.mortals.xhx.module.skin.service.impl;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.module.skin.model.SkinBaseEntity;
import com.mortals.xhx.module.skin.model.SkinBaseQuery;
import com.mortals.xhx.module.skin.model.SkinCategoryQuery;
import com.mortals.xhx.module.skin.service.SkinBaseService;
import com.mortals.xhx.module.skin.service.SkinFieldService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.skin.dao.SkinCategoryDao;
import com.mortals.xhx.module.skin.model.SkinCategoryEntity;
import com.mortals.xhx.module.skin.service.SkinCategoryService;
import org.springframework.util.ObjectUtils;

import java.util.Arrays;
import java.util.List;

/**
 * SkinCategoryService
 * 系统皮肤分类 service实现
 *
 * @author zxfei
 * @date 2022-05-24
 */
@Service("skinCategoryService")
public class SkinCategoryServiceImpl extends AbstractCRUDServiceImpl<SkinCategoryDao, SkinCategoryEntity, Long> implements SkinCategoryService {
    @Autowired
    private SkinFieldService skinFieldService;
    @Autowired
    private SkinBaseService skinBaseService;

    @Override
    protected void validData(SkinCategoryEntity entity, Context context) throws AppException {
        //搜索种类名称唯一
        SkinCategoryEntity skinCategoryEntity = this.selectOne(new SkinCategoryQuery().name(entity.getName()));
        if (!ObjectUtils.isEmpty(skinCategoryEntity) && entity.newEntity()) {
            throw new AppException("分类名称已存在");
        }
        super.validData(entity, context);
    }

    @Override
    protected void findAfter(SkinCategoryEntity entity, PageInfo pageInfo, Context context, List<SkinCategoryEntity> list) throws AppException {
        list.stream().forEach(item -> {
            List<SkinBaseEntity> skinBaseEntities = skinBaseService.find(new SkinBaseQuery().categoryId(item.getId()));
            item.setSkinBaseList(skinBaseEntities);
        });
        super.findAfter(entity, pageInfo, context, list);
    }

    @Override
    protected void removeAfter(Long[] ids, Context context, int result) throws AppException {
        SkinBaseQuery skinBaseQuery = new SkinBaseQuery();
        skinBaseQuery.setCategoryIdList(Arrays.asList(ids));
        Long[] skinBaseIds = skinBaseService.find(skinBaseQuery, context).stream().map(item -> item.getId()).toArray(Long[]::new);
        if (!ObjectUtils.isEmpty(skinBaseIds)) {
            this.skinBaseService.remove(skinBaseIds, context);
        }

        super.removeAfter(ids, context, result);
    }
}