package com.mortals.xhx.module.skin.service.impl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.module.skin.model.SkinBaseEntity;
import com.mortals.xhx.module.skin.model.SkinFieldEntity;
import com.mortals.xhx.module.skin.model.SkinFieldQuery;
import com.mortals.xhx.module.skin.service.SkinFieldService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.skin.dao.SkinTemplateDao;
import com.mortals.xhx.module.skin.model.SkinTemplateEntity;
import com.mortals.xhx.module.skin.service.SkinTemplateService;
import org.springframework.util.ObjectUtils;

import java.util.List;
import java.util.stream.Collectors;

/**
* SkinTemplateService
* 系统皮肤模板 service实现
*
* @author zxfei
* @date 2022-05-24
*/
@Service("skinTemplateService")
public class SkinTemplateServiceImpl extends AbstractCRUDServiceImpl<SkinTemplateDao, SkinTemplateEntity, Long> implements SkinTemplateService {


    @Autowired
    private SkinFieldService skinFieldService;

    @Override
    protected void findAfter(SkinTemplateEntity params, PageInfo pageInfo, Context context, List<SkinTemplateEntity> list) throws AppException {
        list.stream().forEach(item -> {
            List<SkinFieldEntity> skinFieldEntities = skinFieldService.find(new SkinFieldQuery().templateId(item.getId()))
                    .stream().filter(f->f.getSkinId()==null).collect(Collectors.toList());
            item.setSkinFieldList(skinFieldEntities);
        });

        super.findAfter(params, pageInfo, context, list);
    }

    @Override
    protected void saveAfter(SkinTemplateEntity entity, Context context) throws AppException {
        saveSkinFields(entity, context);
        super.saveAfter(entity, context);
    }

    @Override
    protected void updateAfter(SkinTemplateEntity entity, Context context) throws AppException {
        saveSkinFields(entity, context);
        super.updateAfter(entity, context);
    }

    private void saveSkinFields(SkinTemplateEntity entity, Context context) {
        Long[] ids = skinFieldService.find(new SkinFieldQuery().skinId(entity.getId())).stream().map(item -> item.getId()).toArray(Long[]::new);
        if (!ObjectUtils.isEmpty(ids)) {
            skinFieldService.remove(ids, context);
        }
        if (!ObjectUtils.isEmpty(entity.getSkinFieldList())) {
            entity.getSkinFieldList().stream().forEach(item->{
                item.setTemplateId(entity.getId());
            });
            skinFieldService.save(entity.getSkinFieldList(), context);
        }
    }
}