package com.mortals.xhx.module.window.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.model.Context;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.framework.web.BasePhpCRUDJsonMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.window.model.WindowEntity;
import com.mortals.xhx.module.window.service.WindowService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;

/**
 * 站点部门窗口
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("window")
public class WindowController extends BaseCRUDJsonBodyMappingController<WindowService, WindowEntity, Long> {

    @Autowired
    private ParamService paramService;

    public WindowController() {
        super.setFormClass(WindowForm.class);
        super.setModuleDesc("站点部门窗口");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "hongqi", paramService.getParamBySecondOrganize("Window", "hongqi"));
        this.addDict(model, "building", paramService.getParamBySecondOrganize("Window", "building"));
        this.addDict(model, "level", paramService.getParamBySecondOrganize("Window", "level"));
        super.init(model, context);
    }


    /**
     * 添加业务到窗口
     */
    @PostMapping(value = "addBusinessToWindow")
    public String addBusinessToSite(@RequestBody Map<String, Object> map) {
        JSONObject jsonObject = new JSONObject();
        Map<String, Object> model = new HashMap<>();
        String businessIds=(String)map.get("businessIds");
        Long windowId= DataUtil.converObj2Long(map.get("windowId"));
        try {
            this.service.addBusinessToWindow(businessIds,windowId,getContext());
            jsonObject.put(KEY_RESULT_DATA, model);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            jsonObject.put(KEY_RESULT_MSG, "添加业务到窗口成功！");
        } catch (Exception e) {
            log.error("获取异常", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }

}