package com.mortals.xhx.module.workman.service.impl;

import com.mortals.framework.common.code.UserType;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.service.IUser;
import com.mortals.framework.service.impl.AbstractCRUDCacheServiceImpl;
import com.mortals.framework.util.SecurityUtil;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.base.system.role.model.RoleUserQuery;
import com.mortals.xhx.base.system.role.service.RoleUserService;
import com.mortals.xhx.base.system.user.model.UserEntity;
import com.mortals.xhx.base.system.user.model.UserQuery;
import com.mortals.xhx.base.system.user.service.UserService;
import com.mortals.xhx.module.workman.model.WorkmanQuery;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.workman.dao.WorkmanDao;
import com.mortals.xhx.module.workman.model.WorkmanEntity;
import com.mortals.xhx.module.workman.service.WorkmanService;
import org.springframework.util.ObjectUtils;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * WorkmanService
 * 工作人员 service实现
 *
 * @author zxfei
 * @date 2022-01-12
 */
@Service("workmanService")
public class WorkmanServiceImpl extends AbstractCRUDCacheServiceImpl<WorkmanDao, WorkmanEntity, Long> implements WorkmanService {

    @Autowired
    private UserService userService;


    @Override
    protected void saveBefore(WorkmanEntity entity, Context context) throws AppException {

        if (StringUtils.isNull(entity.getLoginName())) {
            throw new AppException("账号不能为空！");
        }

        if (StringUtils.isNull(entity.getLoginPwd())) {
            throw new AppException("密码不能为空！");
        }
        List<WorkmanEntity> list = this.find(new WorkmanQuery().loginName(entity.getLoginName()));
        if (CollectionUtils.isNotEmpty(list)) {
            throw new AppException("账号已存在！");
        }

        doHandlerUser(entity);

        super.saveBefore(entity, context);
    }


    private void doHandlerUser(WorkmanEntity entity) throws AppException {
        if (StringUtils.isNotEmpty(entity.getLoginPwd())) {
            try {
                entity.setLoginPwd(SecurityUtil.md5DoubleEncoding(entity.getLoginPwd()));
            } catch (Exception e) {
                throw new AppException("密码转换异常");
            }
        } else {
            entity.setLoginPwd(null);
        }
    }

    @Override
    protected void updateBefore(WorkmanEntity entity, Context context) throws AppException {
        doHandlerUser(entity);
        super.updateBefore(entity, context);
    }

    @Override
    protected void saveAfter(WorkmanEntity entity, Context context) throws AppException {
        super.saveAfter(entity, context);

    }


    @Override
    public WorkmanEntity doLogin(String loginName, String password) throws AppException {
        WorkmanEntity workmanEntity = this.selectOne(new WorkmanQuery().loginName(loginName));
        if (workmanEntity == null || !workmanEntity.getLoginName().equals(loginName)) {
            throw new AppException("用户名不存在！");
        }
        try {
            if (!workmanEntity.getLoginPwd().equals(SecurityUtil.md5DoubleEncoding(password))) {
                throw new AppException("登录密码错误！");
            }
        } catch (Exception e) {
            throw new AppException("密码验认出错！", e);
        }

        return workmanEntity;
    }

    @Override
    public boolean updateUserPwd(String loginName, String oldPwd, String newPwd) throws AppException {
        WorkmanEntity sysUser = this.selectOne(new WorkmanQuery().loginName(loginName));
        if (sysUser == null || !sysUser.getLoginName().equals(loginName)) {
            throw new AppException("帐号错误！");
        }
        try {
            if (!sysUser.getLoginPwd().equals(SecurityUtil.md5DoubleEncoding(oldPwd))) {
                throw new AppException("原始密码错误！");
            }
        } catch (Exception e) {
            throw new AppException("密码验认出错！", e);
        }
        try {
            sysUser.setLoginPwd(SecurityUtil.md5DoubleEncoding(newPwd));

        } catch (Exception e) {
            throw new AppException("密码转换异常！", e);
        }
        dao.update(sysUser);
        return true;
    }
}