package com.mortals.xhx.module.workman.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.framework.web.BasePhpCRUDJsonMappingController;
import com.mortals.xhx.base.framework.annotation.Operlog;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.base.system.role.model.RoleQuery;
import com.mortals.xhx.base.system.role.model.RoleUserEntity;
import com.mortals.xhx.base.system.role.model.RoleUserQuery;
import com.mortals.xhx.base.system.role.service.RoleService;
import com.mortals.xhx.base.system.role.service.RoleUserService;
import com.mortals.xhx.base.system.user.model.UserEntity;
import com.mortals.xhx.base.system.user.model.UserQuery;
import com.mortals.xhx.base.system.user.service.UserService;
import com.mortals.xhx.module.model.model.ModelQuery;
import com.mortals.xhx.module.model.service.ModelService;
import com.mortals.xhx.module.workman.model.WorkmanEntity;
import com.mortals.xhx.module.workman.model.WorkmanQuery;
import com.mortals.xhx.module.workman.service.WorkmanService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;

import java.util.Map;
import java.util.stream.Collectors;

/**
 * 工作人员
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("workman")
public class WorkmanController extends BaseCRUDJsonBodyMappingController<WorkmanService, WorkmanEntity, Long> {

    @Autowired
    private ParamService paramService;

    public WorkmanController() {
        super.setModuleDesc("工作人员");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "politicalstatus", paramService.getParamBySecondOrganize("Workman", "politicalstatus"));
        this.addDict(model, "dangyuan", paramService.getParamBySecondOrganize("Workman", "dangyuan"));
        this.addDict(model, "starlevel", paramService.getParamBySecondOrganize("Workman", "starlevel"));
        this.addDict(model, "online", paramService.getParamBySecondOrganize("Workman", "online"));

        super.init(model, context);
    }

    /**
     * 工作人员登录
     */
    @PostMapping(value = "doLogin")
    @UnAuth
    public String doLogin(@RequestBody WorkmanEntity query) {
        JSONObject ret = new JSONObject();
        try {
            WorkmanEntity workmanEntity = this.service.doLogin(query.getLoginName(), query.getLoginPwd());
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            ret.put(KEY_RESULT_MSG, "工作人员登录成功！");
            ret.put(KEY_RESULT_DATA, workmanEntity);
            recordSysLog(request, getCurUser(), "工作人员登录成功!");
            return ret.toJSONString();
        } catch (Exception e) {
            log.error("工作人员登录错误", e);
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    @RequestMapping(value = "change/password", method = RequestMethod.POST)
    @UnAuth
    public String changePassword(@RequestBody WorkmanEntity query) {
        JSONObject ret = new JSONObject();
        try {
            boolean bool = service.updateUserPwd(query.getLoginName(), query.getOldPwd(), query.getNewPwd());
            if (bool) {
                ret.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
                ret.put(KEY_RESULT_MSG, "密码修改成功！");
            } else {
                throw new AppException("账户密码修改失败！");
            }
        } catch (Exception e) {
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return ret.toJSONString();
    }
}