-- ----------------------------
-- 用户信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_user`;
CREATE TABLE mortals_xhx_user(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '用户ID，主键，自增长',
    `loginName` varchar(50)     COMMENT '登录名',
    `loginPwd` varchar(128)     COMMENT '登录密码，使用md5双次加密',
    `loginLimitAddress` varchar(200)     COMMENT '登录限制地址，多个IP地址用逗号分隔，可以使用IP段匹配，如：172.17.*非空：则只能该值内的IP可以登录',
    `realName` varchar(64)     COMMENT '用户名',
    `mobile` varchar(21)     COMMENT '用户手机号',
    `phone` varchar(21)     COMMENT '用户联系电话',
    `email` varchar(50)     COMMENT '用户邮箱',
    `qq` varchar(20)     COMMENT 'QQ号码',
    `userType` tinyint(2)     COMMENT '用户类型(0.系统用户,1.普通用户,2.工作人员)',
    `siteIds` varchar(512)     COMMENT '所属站点id,多个逗号分隔',
    `areaCodes` varchar(512)     COMMENT '所属区域code,多个逗号分隔',
    `status` tinyint(2)     COMMENT '用户状态(0.停用，1.正常，2.冻结，3.销户，4.离职)',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `createUserName` varchar(50)     COMMENT '创建用户名称',
    `lastLoginTime` datetime     COMMENT '最后一次登录时间',
    `lastLoginAddress` varchar(21)     COMMENT '最后一次登录地址',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户信息业务';

-- ----------------------------
-- 角色信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role`;
CREATE TABLE mortals_xhx_role(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `name` varchar(128)     COMMENT '角色名称',
    `roleCode` varchar(128)     COMMENT '角色编码',
    `roleSort` int(4)     COMMENT '角色排序字段',
    `roleType` tinyint(2)     COMMENT '角色类型(0.系统内置角色，1.默认系统角色，2.普通角色)',
    `remark` varchar(256)     COMMENT '备注',
    `status` tinyint(2)     COMMENT '角色状态（0.停用，1.启用）',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `createUserName` varchar(50)     COMMENT '创建用户名称',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色信息';

-- ----------------------------
-- 角色用户关联表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role_user`;
CREATE TABLE mortals_xhx_role_user(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `roleId` bigint(20)     COMMENT '角色ID',
    `userId` bigint(20)     COMMENT '用户ID',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色用户关联';

-- ----------------------------
-- 角色菜单权限关联表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role_auth`;
CREATE TABLE mortals_xhx_role_auth(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `roleId` bigint(20)     COMMENT '角色ID',
    `menuId` bigint(20)     COMMENT '菜单ID',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色菜单权限关联';

-- ----------------------------
-- 菜单信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_menu`;
CREATE TABLE mortals_xhx_menu(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '菜单ID，主键，自增长',
    `name` varchar(50)     COMMENT '菜单名称',
    `url` varchar(256)     COMMENT '连接地址',
    `parentId` bigint(20)     COMMENT '父菜单ID，一级菜单的该字段值为-1',
    `linkType` tinyint(2)     COMMENT '链接方式，(0.普通，1.弹出，2.脚本)',
    `imgPath` varchar(128)     COMMENT '主菜单图标，主菜单图标的css样式名',
    `buttonImgPath` varchar(128)     COMMENT '按钮图标',
    `imgCommPath` varchar(128)     COMMENT '常用菜单图标',
    `visible` tinyint(2)     COMMENT '菜单显示(0.隐藏，1.显示)',
    `menuType` tinyint(2)     COMMENT '菜单类型(0.目录，1.菜单，2.按钮)',
    `status` tinyint(2)     COMMENT '菜单状态(0.禁用，1.启用)',
    `authType` tinyint(2)     COMMENT '权限类型(0.无限制，1.无需登录查看，2.需要登录查看，3.需要角色权限查看)',
    `orderId` int(4)     COMMENT '排序编号',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `createUserName` varchar(50)     COMMENT '创建用户名称',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='菜单信息业务';

-- ----------------------------
-- 上传文件业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_uploadfile`;
CREATE TABLE mortals_xhx_uploadfile(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT 'ID，主键，自增长',
    `fileName` varchar(50)     COMMENT '文件名称',
    `filePath` varchar(100)     COMMENT '文件路径',
    `fileType` tinyint(2)     COMMENT '文件类型，(1.excel ,2. img,3.zip, 4.pdf)',
    `createTime` datetime     COMMENT '创建时间',
    `createUser` varchar(50)     COMMENT '创建用户',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='上传文件业务';

-- ----------------------------
-- API服务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_system_service_api`;
CREATE TABLE mortals_xhx_system_service_api(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '系统API的ID，主键，自增长',
    `systemServiceName` varchar(10)     COMMENT '模块名称',
    `systemServiceCode` varchar(20)     COMMENT '模块编码',
    `systemServiceUrl` varchar(50)     COMMENT '模块地址',
    `apiName` varchar(20)     COMMENT 'API接口名称',
    `apiUrl` varchar(200)     COMMENT 'API接口（链接）',
    `apiVersion` varchar(5)     COMMENT 'API接口版本',
    `apiStatus` tinyint(2)     COMMENT 'API接口状态(1:启用,0:停用)',
    `createTime` datetime     COMMENT '创建时间',
    `lapseTime` datetime     COMMENT '失效时间',
    `apiRemark` varchar(200)     COMMENT 'API接口说明',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='API服务';

-- ----------------------------
-- API服务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_system_service`;
CREATE TABLE mortals_xhx_system_service(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '系统API的ID，主键，自增长',
    `systemServiceName` varchar(10)     COMMENT '模块名称',
    `systemServiceCode` varchar(20)     COMMENT '模块编码',
    `systemServiceUrl` varchar(50)     COMMENT '模块地址',
    `packageName` varchar(20)     COMMENT '包名称',
    `packagePath` varchar(200)     COMMENT '包的下载路径',
    `packageVersion` varchar(5)     COMMENT '包的版本',
    `apiStatus` tinyint(2)     COMMENT '包的状态(1:启用,0:停用)',
    `createTime` datetime     COMMENT '创建时间',
    `lapseTime` datetime     COMMENT '失效时间',
    `packageRemark` varchar(200)     COMMENT '包的说明',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='API服务';

-- ----------------------------
-- 参数信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_param`;
CREATE TABLE mortals_xhx_param(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `name` varchar(100)     COMMENT '参数名称',
    `firstOrganize` varchar(100)     COMMENT '一级组织，如：平台配置',
    `secondOrganize` varchar(100)     COMMENT '二级组织，如：基础配置',
    `paramKey` varchar(100)     COMMENT '参数键，全局唯一',
    `paramValue` varchar(2000)     COMMENT '参数值',
    `validStatus` tinyint(2)     COMMENT '参数有效状态，(0.禁用，1.启用)',
    `modStatus` tinyint(2)     COMMENT '参数修改状态(0.隐藏，1.页面仅查看，2.页面可修改，3.页面可删除，4.页面可修改删除)',
    `displayType` tinyint(2)     COMMENT '展现类型(0.普通文本框，1.多行文本框，2.开关，3.块输入框)',
    `remark` varchar(200)     COMMENT '备注',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `createUserName` varchar(50)     COMMENT '创建用户名称',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='参数信息业务';

-- ----------------------------
-- 任务信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_task`;
CREATE TABLE mortals_xhx_task(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `name` varchar(100)     COMMENT '任务名称',
    `taskKey` varchar(100)     COMMENT '任务关键字，区分任务执行流程',
    `status` tinyint(2)     COMMENT '任务状态，(0,未启动，1.执行中)',
    `excuteService` varchar(100)     COMMENT '任务执行服务',
    `excuteParam` text     COMMENT '任务执行参数',
    `excuteHost` varchar(200)     COMMENT '任务执行主机，为空表示不限制任务的执行主机，多个用逗号分隔',
    `excuteStrategy` tinyint(2)     COMMENT '执行策略(1.按日，2.按周，3.按月，4.按间隔时间)',
    `excuteDate` int(11)     COMMENT '执行日期，按日：则为0；按周：则为1-7；按月：则为：1-31；按间隔时间：则为间隔时间，单位：秒；',
    `excuteTime` varchar(10)     COMMENT '执行时间，格式：HH:mm，',
    `remark` varchar(200)     COMMENT '备注',
    `lastExcuteHost` varchar(32)     COMMENT '最后执行主机',
    `lastExcuteTime` datetime     COMMENT '最后执行时间',
    `interimExcuteStatus` tinyint(2)     COMMENT '临时执行状态，(0.未启用，1.立即执行并保留，2.立即执行并删除)',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `createUserName` varchar(50)     COMMENT '创建用户名称',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='任务信息业务';

-- ----------------------------
-- 操作日志业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_oper_log`;
CREATE TABLE mortals_xhx_oper_log(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '序号，主键，自增长',
    `platformMark` varchar(50)     COMMENT '平台标识',
    `userId` bigint(20)     COMMENT '用户id',
    `userName` varchar(50)     COMMENT '用户名称',
    `loginName` varchar(50)     COMMENT '用户登录名',
    `requestUrl` varchar(200)     COMMENT '请求地址',
    `content` varchar(2000)     COMMENT '操作内容，记录操作具体信息，如修改前修改或的数据',
    `ip` varchar(30)     COMMENT '操作IP地址',
    `logDate` datetime     COMMENT '操作时间',
    `operType` tinyint(2)     COMMENT '操作类型，(0.新增,1.修改,2.删除)',
    `createTime` datetime     COMMENT '创建时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='操作日志业务';


-- ----------------------------
-- Records of mortals_xhx_task
-- ----------------------------
INSERT INTO `mortals_xhx_task` VALUES (2, '分表创建任务', 'tableIndexService', 0, 'tableIndexService', NULL, NULL, 1, 0, '00:30', NULL, '192.168.1.106', '2021-08-18 00:30:01', 0, '2021-08-12 11:07:23', 1, '系统管理员');


INSERT INTO `mortals_xhx_user` VALUES (1, 'admin', '43442676c74ae59f219c2d87fd6bad52', NULL, '系统管理员', '13808095770', NULL, NULL,NULL, 0,"","", 1, now(), 1, 'admin', now(), '127.0.0.1');