package com.mortals.xhx.busiz.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.busiz.rsp.ApiResp;
import com.mortals.xhx.common.code.ApiRespCodeEnum;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.pdu.user.UserPdu;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.feign.req.BaseUserQuery;
import com.mortals.xhx.feign.req.BaseUserReq;
import com.mortals.xhx.feign.rsp.UserRsp;
import com.mortals.xhx.module.user.model.UserQuery;
import com.mortals.xhx.module.user.service.UserService;
import lombok.extern.apachecommons.CommonsLog;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 用户对外服务接口
 *
 * @author: zxfei
 * @date: 2022/5/30 11:04
 */
@RestController
@CommonsLog
@RequestMapping("/api/user")
public class UserApiController {
    @Autowired
    private UserService userService;

    /**
     * 用户列表
     * @param req
     * @return
     */
    @PostMapping("/findAllUser")
    public ApiResp<UserRsp> findAllUser(@RequestBody BaseUserReq<BaseUserQuery> req) {
        ApiResp<UserRsp> rsp = new ApiResp<>();
        rsp.setMsg(ApiRespCodeEnum.SUCCESS.getLabel());
        rsp.setCode(ApiRespCodeEnum.SUCCESS.getValue());
        PageInfo page = new PageInfo();
        page.setPrePageResult(-1);
        UserRsp userRsp = new UserRsp();
        try {
            if (!ObjectUtils.isEmpty(req.getPage())) {
                page.setPrePageResult(req.getPage().getPer() == 0 ? -1 : req.getPage().getPer());
                page.setCurrPage(req.getPage().getSize() == 0 ? 1 : req.getPage().getSize());
            }

            UserQuery userQuery = new UserQuery();
            BeanUtils.copyProperties(req.getQuery(), userQuery, BeanUtil.getNullPropertyNames(req.getQuery()));
            List<UserPdu> collect = userService.find(userQuery, page, null).getList().stream().map(item -> {
                UserPdu userPdu = new UserPdu();
                BeanUtils.copyProperties(item, userPdu, BeanUtil.getNullPropertyNames(item));
                return userPdu;

            }).collect(Collectors.toList());
            userRsp.setList(collect);
            userRsp.setPage(req.getPage());
        } catch (Exception e) {
            log.error("获取用户列表异常", e);
            rsp.setCode(YesNoEnum.NO.getValue());
            rsp.setMsg(e.getMessage());
            return rsp;
        }
        rsp.setData(userRsp);
        log.info("响应【用户列表】【响应体】-->  " + JSONObject.toJSONString(rsp));
        return rsp;
    }

}
