package com.mortals.xhx.module.area.service.impl;

import com.alibaba.fastjson.JSON;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.pdu.SitePdu;
import com.mortals.xhx.feign.area.IApiAreaFeign;
import com.mortals.xhx.module.area.model.AreaEntity;
import com.mortals.xhx.module.area.model.AreaQuery;
import com.mortals.xhx.feign.rsp.ApiResp;
import com.mortals.xhx.module.area.dao.AreaDao;
import com.mortals.xhx.module.area.service.AreaService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.util.stream.Collectors;

/**
 * AreaService
 * 区域 service实现
 *
 * @author zxfei
 * @date 2022-01-12
 */
@Service("areaService")
@Slf4j
public class AreaServiceImpl extends AbstractCRUDServiceImpl<AreaDao, AreaEntity, Long> implements AreaService {

    @Autowired
    private IApiAreaFeign apiAreaFeign;


    @Override
    public String getListByParentId(String parentId, Context context) {
        if (ObjectUtils.isEmpty(parentId)) {
            parentId = "0";
        }
        String resp = apiAreaFeign.getListByParentId(parentId);

        ApiResp apiResp = JSON.parseObject(resp, ApiResp.class);
        if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
            throw new AppException("获取区域数据失败：" + apiResp.getMsg());
        }
        log.info("getListByParentId=>{}", resp);
        return resp;

    }

    @Override
    public String viewArea(Long id, Context context) {
        String resp = apiAreaFeign.viewAreaInfo(id);
        ApiResp apiResp = JSON.parseObject(resp, ApiResp.class);
        if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
            throw new AppException("获取区域数据失败：" + apiResp.getMsg());
        }
        log.info("viewArea=>{}", resp);
        return resp;
    }

    @Override
    public String list(AreaEntity query, Context context) {
        log.info("areaListReq==》{}", JSON.toJSONString(query));
        String resp = apiAreaFeign.list(query);
        ApiResp apiResp = JSON.parseObject(resp, ApiResp.class);
        if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
            throw new AppException("获取区域列表数据失败：" + apiResp.getMsg());
        }
        log.info("listAreaResp=>{}", resp);
        return resp;
    }

    @Override
    public String treeselect(Context context) {
        log.info("treeselectReq==");
        String resp = apiAreaFeign.treeselect();
        ApiResp apiResp = JSON.parseObject(resp, ApiResp.class);
        if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
            throw new AppException("获取区域列表树数据失败：" + apiResp.getMsg());
        }
       //log.info("treeselectResp=>{}", resp);
        return resp;
    }

    @Override
    public String getFlatSitesByAreaCodes(AreaQuery query, Context context) {
        log.info("getFlatSitesByAreaIds=={}",JSON.toJSONString(query));
        SitePdu sitePdu = new SitePdu();
        sitePdu.setAreaCodeList(query.getAreaCodeList());
        String resp = apiAreaFeign.getFlatSitesByAreaIds(sitePdu);
        ApiResp apiResp = JSON.parseObject(resp, ApiResp.class);
        if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
            throw new AppException("获取区域列表树数据失败：" + apiResp.getMsg());
        }
        log.info("getFlatSitesByAreaIds=>{}", resp);
        return resp;
    }

}