package com.mortals.xhx.module.area.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.IAuthTokenService;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.area.model.AreaEntity;
import com.mortals.xhx.module.area.model.AreaQuery;
import com.mortals.xhx.module.area.model.AreaTreeSelect;
import com.mortals.xhx.module.area.service.AreaService;
import com.mortals.xhx.module.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 区域
 *
 * @author zxfei
 * @date 2022-01-19
 */
@RestController
@RequestMapping("area")
public class AreaController extends BaseCRUDJsonBodyMappingController<AreaService, AreaEntity, Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private IAuthTokenService authTokenService;

    public AreaController() {
        super.setModuleDesc("区域");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "haveSonArea", paramService.getParamBySecondOrganize("Area", "haveSonArea"));
        this.addDict(model, "haveSonDept", paramService.getParamBySecondOrganize("Area", "haveSonDept"));
        this.addDict(model, "haveGetDept", paramService.getParamBySecondOrganize("Area", "haveGetDept"));
        this.addDict(model, "haveGetMatterList", paramService.getParamBySecondOrganize("Area", "haveGetMatterList"));
        this.addDict(model, "areaLevel", paramService.getParamBySecondOrganize("Area", "areaLevel"));
        this.addDict(model, "status", paramService.getParamBySecondOrganize("Area", "status"));
        super.init(model, context);
    }


    @Override
    public String view(Long id) {
        if (id == null) {
            return this.createFailJsonResp("请选择待查看" + this.getModuleDesc() + "信息");
        } else {
            String busiDesc = "查看" + this.getModuleDesc();
            Context context = this.getContext();
            try {
                String resp = this.service.viewArea(id, context);
                this.recordSysLog(this.request, busiDesc + " 【成功】");
                return resp;
            } catch (Exception e) {
                this.doException(this.request, busiDesc, null, e);
                return this.createFailJsonResp(e.getMessage() == null ? "系统异常" : e.getMessage());
            }
        }
    }


    /**
     * 获取站点下拉树列表
     */
    @PostMapping("treeselect")
    public String treeselect() {
        Map<String, Object> model = new HashMap<>();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();
        try {
            String resp = this.service.treeselect(context);
            recordSysLog(request, busiDesc + " 【成功】");
            return  resp;
        } catch (Exception e) {
            this.doException(request, busiDesc, model, e);
            return this.createFailJsonResp(e.getMessage() == null ? "系统异常" : e.getMessage());
        }
    }


    /**
     * 根据parentId查询子信息
     */
    @GetMapping(value = "getListByParentId")
    public String getListByParentId(String parentId) {
        JSONObject ret = new JSONObject();
        Map<String, Object> model = new HashMap<>();
        String busiDesc = "查询" + this.getModuleDesc() + "子节点";
        try {
            String retStr = this.service.getListByParentId(parentId, getContext());
            recordSysLog(request, busiDesc + "【成功】");
            return retStr;
        } catch (Exception e) {
            log.error("根据parentId查询子信息错误", e);
            this.doException(request, busiDesc, model, e);
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, e.getMessage());
        }
        return ret.toJSONString();
    }




}