package com.mortals.xhx.module.user.service;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.ICRUDService;
import com.mortals.framework.service.IUser;
import com.mortals.xhx.module.menu.model.MenuEntity;
import com.mortals.xhx.module.user.model.UserEntity;
import com.mortals.xhx.module.user.model.UserEntityExt;

import java.util.List;
import java.util.Set;

/**
* UserService
*
* 用户信息业务 service接口
*
* @author zxfei
* @date 2022-05-25
*/
public interface UserService extends ICRUDService<UserEntity,Long>{
    /**
     * 用户登录
     *
     * @param loginName 登录用户名
     * @param password  登录密码
     * @param loginIp   登录IP
     * @return
     * @throws AppException
     */
    UserEntity doLogin(String loginName, String password, String loginIp) throws AppException;

    /**
     * 校验用户名与密码是否正确
     *
     * @param loginName
     * @param password
     * @return
     * @throws AppException
     */
    UserEntity doCheckUser(String loginName, String password) throws AppException;

    /**
     * 检查用户是否存在
     *
     * @param loginName 登录用户名
     * @param userId    密码
     * @return
     */
    boolean existUser(String loginName, Long userId) throws AppException;

    /**
     * 用户修改密码
     *
     * @param loginName
     * @param oldPwd
     * @param newPwd
     * @return
     * @throws AppException
     */
    boolean updateUserPwd(String loginName, String oldPwd, String newPwd) throws AppException;

    Result<UserEntityExt> findExt(UserEntity params, PageInfo pageInfo, Context context) throws AppException;


    void siteAuth(UserEntityExt entityExt,Context context);

}