package com.mortals.xhx.module.user.service.impl;

import com.mortals.framework.ap.SysConstains;
import com.mortals.framework.common.code.UserType;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.util.SecurityUtil;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.module.area.model.AreaQuery;
import com.mortals.xhx.module.area.service.AreaService;
import com.mortals.xhx.module.menu.service.MenuService;
import com.mortals.xhx.module.role.model.RoleUserQuery;
import com.mortals.xhx.module.role.service.RoleService;
import com.mortals.xhx.module.role.service.RoleUserService;
import com.mortals.xhx.module.user.dao.UserDao;
import com.mortals.xhx.module.user.model.UserEntity;
import com.mortals.xhx.module.user.model.UserEntityExt;
import com.mortals.xhx.module.user.model.UserQuery;
import com.mortals.xhx.module.user.service.UserService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.util.*;
import java.util.stream.Collectors;

/**
 * UserService
 * 用户信息业务 service实现
 *
 * @author zxfei
 * @date 2022-05-25
 */
@Service("userService")
public class UserServiceImpl extends AbstractCRUDServiceImpl<UserDao, UserEntity, Long> implements UserService {
    @Autowired
    private MenuService menuService;
    @Autowired
    private RoleUserService roleUserService;
    @Autowired
    private RoleService roleService;
    @Autowired
    private AreaService areaService;


/*    @Override
    protected void findAfter(UserEntity entity, PageInfo pageInfo, Context context, List<UserEntity> list) throws AppException {
        Map<Long, String> roleMap = roleService.find(new RoleQuery()).stream().collect(Collectors.toMap(x -> x.getId(), y -> y.getName()));
        List<Long> userIdList = list.stream().map(item -> item.getId()).collect(Collectors.toList());
        RoleUserQuery roleUserQuery = new RoleUserQuery();
        roleUserQuery.setUserIdList(userIdList);
        Map<Long, List<RoleUserEntity>> collect = roleUserService.find(roleUserQuery).stream().collect(Collectors.groupingBy(item -> item.getUserId()));
        list.stream().forEach(item->{
            if(!ObjectUtils.isEmpty(collect.get(item.getId()))){
                item.setRoleId(collect.get(item.getId()).stream().map(RoleUserEntity::getRoleId).map(String::valueOf).collect(Collectors.joining(",")));
                item.setRoleName(collect.get(item.getId()).stream().map(m->roleMap.get(m.getRoleId())).filter(f->f!=null).collect(Collectors.joining(",")));
            }
        });
        super.findAfter(entity, pageInfo, context, list);
    }*/

    private void doHandlerUser(UserEntity entity) throws AppException {
        if (StringUtils.isNotEmpty(entity.getLoginPwd())) {
            try {
                entity.setLoginPwd(SecurityUtil.md5DoubleEncoding(entity.getLoginPwd()));
            } catch (Exception e) {
                throw new AppException("密码转换异常");
            }
        } else {
            entity.setLoginPwd(null);
        }
        if (entity.isSystemUser()) {
            entity.setUserType(UserType.SYSTEM.getValue());
        } else {
            entity.setUserType(UserType.CUSTOMER.getValue());
        }


    }

    @Override
    protected void saveBefore(UserEntity entity, Context context) throws AppException {
        this.doHandlerUser(entity);
    }

    @Override
    protected void updateBefore(UserEntity entity, Context context) throws AppException {
        if (entity.getId().longValue() == SysConstains.ADMIN_ID && !context.getUser().isAdmin()) {
            throw new AppException("你没有权限执行该操作");
        }
        this.doHandlerUser(entity);
        if (!ObjectUtils.isEmpty(entity.getRoleId())) {
            RoleUserQuery roleUserQuery = new RoleUserQuery();
            roleUserQuery.setUserId(entity.getId());
            roleUserQuery.setRoleIdList(Arrays.asList(Long.parseLong(entity.getRoleId())));
            roleUserService.assignRoleToUser(roleUserQuery);
        }
    }


    public UserEntity findByLoginName(String loginName) {
        UserQuery params = new UserQuery();
        params.setLoginName(loginName);
        return this.selectOne(params);
    }

    @Override
    public UserEntity doLogin(String loginName, String password, String loginIp) throws AppException {
        UserEntity sysUser = this.findByLoginName(loginName);
        if (sysUser == null || !sysUser.getLoginName().equals(loginName)) {
            throw new AppException("用户名不存在！");
        }
        try {
            if (!sysUser.getLoginPwd().equals(SecurityUtil.md5DoubleEncoding(password))) {
                throw new AppException("登录密码错误！");
            }
        } catch (Exception e) {
            throw new AppException("密码验认出错！", e);
        }

        return sysUser;
    }

    @Override
    public UserEntity doCheckUser(String loginName, String password) throws AppException {
        UserEntity sysUser = this.findByLoginName(loginName);
        if (sysUser == null || !sysUser.getLoginName().equals(loginName)) {
            return null;
        }
        try {
            if (!sysUser.getLoginPwd().equals(SecurityUtil.md5DoubleEncoding(password))) {
                return null;
            }
        } catch (Exception e) {
            return null;
        }
        return sysUser;
    }

    @Override
    public boolean existUser(String loginName, Long userId) throws AppException {
        UserEntity sysUser = this.findByLoginName(loginName);
        boolean bRet = false;
        if (sysUser != null) {
            if (userId == null || userId == 0 || userId.longValue() != sysUser.getId().longValue()) {
                bRet = true;
            }
        }
        return bRet;
    }

    @Override
    public boolean updateUserPwd(String loginName, String oldPwd, String newPwd) throws AppException {
        UserEntity sysUser = this.findByLoginName(loginName);
        if (sysUser == null || !sysUser.getLoginName().equals(loginName)) {
            throw new AppException("帐号错误！");
        }
        try {
            if (!sysUser.getLoginPwd().equals(SecurityUtil.md5DoubleEncoding(oldPwd))) {
                throw new AppException("原始密码错误！");
            }
        } catch (Exception e) {
            throw new AppException("密码验认出错！", e);
        }
        try {
            sysUser.setLoginPwd(SecurityUtil.md5DoubleEncoding(newPwd));
        } catch (Exception e) {
            throw new AppException("密码转换异常！", e);
        }
        dao.update(sysUser);
        return true;
    }

    @Override
    public Result<UserEntityExt> findExt(UserEntity params, PageInfo pageInfo, Context context) throws AppException {
        UserQuery query = new UserQuery();
        BeanUtils.copyProperties(params, query);
        if (StringUtils.isNotEmpty(params.getQuery())) {
            StringBuffer condition = new StringBuffer("%");
            condition.append(params.getQuery()).append("%");
            UserQuery condition1 = new UserQuery();
            UserQuery condition2 = new UserQuery();
            UserQuery condition3 = new UserQuery();
            UserQuery condition4 = new UserQuery();
            condition1.setPhone(condition.toString());
            condition2.setMobile(condition.toString());
            condition3.setLoginName(condition.toString());
            condition4.setRealName(condition.toString());
            List<UserQuery> orConditionList = new ArrayList<>();
            orConditionList.add(condition1);
            orConditionList.add(condition2);
            orConditionList.add(condition3);
            orConditionList.add(condition4);
            query.setOrConditionList(orConditionList);
        }
        return getDao().getListExt(query, pageInfo);
    }

    @Override
    public void siteAuth(UserEntityExt entityExt, Context context) {
        if (!ObjectUtils.isEmpty(entityExt.getUserId())) {
            throw new AppException("用户ID不能为空！");
        }
        String siteIds = areaService.getFlatSitesByAreaCodes(new AreaQuery().areaCodeList(entityExt.getAreaCodeList()), context);
        UserEntity userEntity = this.get(entityExt.getUserId(), context);
        userEntity.setAreaCodes(entityExt.getAreaCodeList().stream().collect(Collectors.joining(",")));
        userEntity.setSiteIds(siteIds);
        this.update(userEntity, context);
    }


    @Override
    protected void saveAfter(UserEntity entity, Context context) throws AppException {
        super.saveAfter(entity, context);
        if (!ObjectUtils.isEmpty(entity.getRoleId())) {
            RoleUserQuery roleUserQuery = new RoleUserQuery();
            roleUserQuery.setUserId(entity.getId());
            roleUserQuery.setRoleIdList(Arrays.asList(Long.parseLong(entity.getRoleId())));
            roleUserService.assignRoleToUser(roleUserQuery);
        }
    }

    @Override
    protected void updateAfter(UserEntity entity, Context context) throws AppException {
        super.updateAfter(entity, context);
    }
}